@@ -3,7 +3,7 @@ import time
 
 from nextline import Nextline
 
-from nextline_schedule.auto import Machine, build_machine
+from nextline_schedule.auto import AutoModeStateMachine, build_auto_mode_state_machine
 
 
 def f():
@@ -18,7 +18,9 @@ async def test_turn_off_while_waiting():
 
     run_no = 1
     nextline = Nextline(statement=f, run_no_start_from=run_no, timeout_on_exit=60)
-    auto_mode = build_machine(nextline=nextline, request_statement=request_statement)
+    auto_mode = build_auto_mode_state_machine(
+        nextline=nextline, request_statement=request_statement
+    )
 
     states = asyncio.create_task(subscribe_state(auto_mode))
 
@@ -39,5 +41,5 @@ async def test_turn_off_while_waiting():
     assert expected == await states
 
 
-async def subscribe_state(auto_mode: Machine):
+async def subscribe_state(auto_mode: AutoModeStateMachine):
     return [state async for state in auto_mode.subscribe_state()]
